@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2022  Jean-Philippe Lang
+# Copyright (C) 2006-2023  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -693,8 +693,8 @@ module IssuesHelper
   def issue_history_tabs
     tabs = []
     if @journals.present?
-      journals_without_notes = @journals.select{|value| value.notes.blank?}
-      journals_with_notes = @journals.reject{|value| value.notes.blank?}
+      has_details = @journals.any? {|value| value.details.present?}
+      has_notes = @journals.any? {|value| value.notes.present?}
       tabs <<
         {
           :name => 'history',
@@ -703,7 +703,7 @@ module IssuesHelper
           :partial => 'issues/tabs/history',
           :locals => {:issue => @issue, :journals => @journals}
         }
-      if journals_with_notes.any?
+      if has_notes
         tabs <<
           {
             :name => 'notes',
@@ -711,7 +711,7 @@ module IssuesHelper
             :onclick => 'showIssueHistory("notes", this.href)'
           }
       end
-      if journals_without_notes.any?
+      if has_details
         tabs <<
           {
             :name => 'properties',
@@ -764,12 +764,18 @@ module IssuesHelper
   end
 
   def projects_for_select(issue)
-    if issue.parent_issue_id.present?
-      issue.allowed_target_projects_for_subtask(User.current)
-    elsif @project && issue.new_record? && !issue.copy?
-      issue.allowed_target_projects(User.current, 'tree')
+    projects =
+      if issue.parent_issue_id.present?
+        issue.allowed_target_projects_for_subtask(User.current)
+      elsif @project && issue.new_record? && !issue.copy?
+        issue.allowed_target_projects(User.current, 'tree')
+      else
+        issue.allowed_target_projects(User.current)
+      end
+    if issue.read_only_attribute_names(User.current).include?('project_id')
+      params['project_id'].present? ? Project.where(identifier: params['project_id']) : projects
     else
-      issue.allowed_target_projects(User.current)
+      projects
     end
   end
 end
